# fast-luks-py
**Repository under construction.**

Python scripts for storage encryption through LUKS. Converted into python from the bash scripts of [fast-luks](https://github.com/Laniakea-elixir-it/fast-luks)
